==> zio-aws-lightsail_2.12-5.17.295.6-sources.jar: zio/aws/lightsail/model/GetActiveNamesResponse.scala <==
package zio.aws.lightsail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetActiveNamesResponse(
    activeNames: Optional[Iterable[String]] = Optional.Absent,
    nextPageToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.GetActiveNamesResponse = {
    import GetActiveNamesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.GetActiveNamesResponse
      .builder()
      .optionallyWith(
        activeNames.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.activeNames)
      .optionallyWith(nextPageToken.map(value => value: java.lang.String))(
        _.nextPageToken
      )
      .build()
  }
  def asReadOnly: zio.aws.lightsail.model.GetActiveNamesResponse.ReadOnly =
    zio.aws.lightsail.model.GetActiveNamesResponse.wrap(buildAwsValue())
}
object GetActiveNamesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.GetActiveNamesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.GetActiveNamesResponse =
      zio.aws.lightsail.model.GetActiveNamesResponse(
        activeNames.map(value => value),
        nextPageToken.map(value => value)
      )
    def activeNames: Optional[List[String]]
    def nextPageToken: Optional[String]
    def getActiveNames: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("activeNames", activeNames)
    def getNextPageToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextPageToken", nextPageToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.GetActiveNamesResponse
  ) extends zio.aws.lightsail.model.GetActiveNamesResponse.ReadOnly {
    override val activeNames: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.activeNames())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val nextPageToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextPageToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.GetActiveNamesResponse
  ): zio.aws.lightsail.model.GetActiveNamesResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-lightsail_2.13-5.17.104.4-sources.jar: zio/aws/lightsail/model/GetActiveNamesResponse.scala <==
package zio.aws.lightsail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetActiveNamesResponse(
    activeNames: Option[Iterable[String]] = None,
    nextPageToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.GetActiveNamesResponse = {
    import GetActiveNamesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.GetActiveNamesResponse
      .builder()
      .optionallyWith(
        activeNames.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.activeNames)
      .optionallyWith(nextPageToken.map(value => value: java.lang.String))(
        _.nextPageToken
      )
      .build()
  }
  def asReadOnly: zio.aws.lightsail.model.GetActiveNamesResponse.ReadOnly =
    zio.aws.lightsail.model.GetActiveNamesResponse.wrap(buildAwsValue())
}
object GetActiveNamesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.GetActiveNamesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.GetActiveNamesResponse =
      zio.aws.lightsail.model.GetActiveNamesResponse(
        activeNames.map(value => value),
        nextPageToken.map(value => value)
      )
    def activeNames: Option[List[String]]
    def nextPageToken: Option[String]
    def getActiveNames: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("activeNames", activeNames)
    def getNextPageToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextPageToken", nextPageToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.GetActiveNamesResponse
  ) extends zio.aws.lightsail.model.GetActiveNamesResponse.ReadOnly {
    override val activeNames: Option[List[String]] = scala
      .Option(impl.activeNames())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val nextPageToken: Option[String] =
      scala.Option(impl.nextPageToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.GetActiveNamesResponse
  ): zio.aws.lightsail.model.GetActiveNamesResponse.ReadOnly = new Wrapper(impl)
}
